<?php
# Author: Lê Huỳnh Tòng
# Admin: LarVPS.com
# Email: info@lar.vn

require_once "lib/zip/zip.php";
require_once "lib/Ifsnop/Mysqldump/Mysqldump.php";

function get_wp_config() {
    $content = @file_get_contents( '../wp-config.php' );

    if( ! $content ) {
        return false;
    }
    $params = [
        'db_name' => "/define.+?'DB_NAME'.+?'(.*?)'.+/",
        'db_user' => "/define.+?'DB_USER'.+?'(.*?)'.+/",
        'db_password' => "/define.+?'DB_PASSWORD'.+?'(.*?)'.+/",
        'db_host' => "/define.+?'DB_HOST'.+?'(.*?)'.+/",
    ];

    $return = [];
    foreach( $params as $key => $value ) {
        $found = preg_match_all( $value, $content, $result );
        if( $found ) {
            $return[ $key ] = $result[ 1 ][ 0 ];
        } else {
            $return[ $key ] = false;
        }
    }

    return $return;
}

function clean_input($input) {
   $input = htmlspecialchars($input, ENT_IGNORE, 'utf-8');
   $input = strip_tags($input);
   $input = stripslashes($input);
   return $input;
}

if ( ! is_array(get_wp_config())) {
	echo "Không tìm thấy wp-config.php. Vui lòng upload backup vào thư mục public_html.";
	exit;
}

if (isset($_POST['submit'])) {

	ini_set('max_execution_time', 0);
	ini_set('memory_limit', '1024M');

	if ( !isset($_POST['db_name']) && !isset($_POST['db_user']) && !isset($_POST['db_password']) ) {
		echo "Vui lòng nhập các dữ liệu còn trống";
		exit;	
	}

	// remove file old backup
	@unlink('../backup.zip');
	@unlink('../database.sql');

	$folder_path = dirname(dirname(__FILE__));
	$file_name = 'backup.zip';
	$backup_path = $folder_path.'/'.$file_name;

	// mysql
	$domain = clean_input($_POST['url']);
	$db_name = clean_input($_POST['db_name']);
	$db_user = clean_input($_POST['db_user']);
	$db_password = $_POST['db_password'];
	$db_host = clean_input($_POST['db_host']);
	$dir = $folder_path.'/database.sql';

	// backup database
	try {
	    $dump = new Ifsnop\Mysqldump\Mysqldump('mysql:host='.$db_host.';dbname='.$db_name, $db_user, $db_password);
	    $dump->start($dir);
	} catch (\Exception $e) {
	    echo $e->getMessage();
	    exit;	
	    
	}

	// zip folder
	$zip = new Zip();
	$zip->zip_start($backup_path);
	$zip->zip_add($folder_path);
	$zip->zip_end();

	$success = 1;
}
?>

<!DOCTYPE html>
<html lang="en">
	<head>
		<!-- Required meta tags -->
		<meta charset="utf-8">
		<meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
		<title>Backup - LarVPS</title>
        <link href="output.css" rel="stylesheet">
	</head>
	<body>
		 <div class="w-1/2 bg-gray-100 border p-3 rounded" style=" margin: 30px auto">
		 	<div class="mb-3">
		 		<h3 class="text-2xl text-gray-900 font-semibold">Backup & Restore - LarVPS</h3>
		 		<p class="text-gray-600"> Công cụ giúp Backup/Restore mã nguồn Wordpress từ hosting/vps sang LarVPS</p>
		 	</div>

 			 <form action="" method="POST" class="form bg-white p-6 relative">
	                <div class="mb-4">
	                	<label for="url"><strong>URL</strong></label>
	                    <input type="text" id="url" name="url" placeholder="Tên miền của bạn kèm http hoặc https. ví dụ: https://abc.com" value="<?php echo $_SERVER['HTTP_HOST']; ?>" class="border rounded p-2 mt-2 w-full">
	                </div>

	                <div class="my-4">
	                	<label for="db_name"><strong>DB_NAME</strong></label>
	                	<input type="text" name="db_name" id="db_name" placeholder="DB_NAME" class="border rounded p-2 w-full mt-2" value="<?php echo get_wp_config()['db_name']; ?>">
	                </div>


	                <div class="my-4">
	                	<label for="db_user"><strong>DB_USER</strong></label>
	                	<input type="text" name="db_user" id="db_user" placeholder="DB_USER" class="border rounded p-2 w-full mt-2" value="<?php echo get_wp_config()['db_user']; ?>">
	                </div>

	                <div class="my-4">
	                	<label for="db_user"><strong>DB_PASSWORD</strong></label>
	                	<input type="text" name="db_password" placeholder="DB_PASSWORD" class="border rounded p-2 w-full mt-3" value="<?php echo get_wp_config()['db_password']; ?>">
	                <div>

	                <div class="my-4">
	                	<label for="db_user"><strong>DB_HOST</strong></label>
	                	<input type="text" name="db_host" placeholder="DB_HOST" class="border rounded p-2 w-full mt-3" value="<?php echo get_wp_config()['db_host']; ?>">
	               	</div>

	               	<button name="submit" class="w-full mt-6 bg-blue-600 hover:bg-blue-500 text-white font-semibold p-3 rounded">Backup ngay</button>

	               	<p class="text-center">
	               		<small>Sau khi bấm vào nút backup ngay, bạn vui lòng đợi trong ít phút, sẽ có thông báo backup thành công.	</small>
	               	</p>
	               
 	         </form>

 	         <?php if (!empty($success)): ?>
 	         		<div class="my-4">
 	         			<h2>Bạn đã backup thành công</h2>
 	         			<ul>
 	         				<li>
 	         					Download file backup: <a href="//<?php echo $_SERVER['HTTP_HOST'] ?>/backup.zip">Download</a>
 	         				</li>
 	         				<li>
 	         					Restore sang LarVPS: larvps restore <?php echo "$domain".' "'.$db_name.'" "'.$db_user.'" "'.$db_password.'"' ?>

 	         				</li>
 	         			</ul>
 	         		</div>
 	         <?php endif ?>
 	 
		 </div>
	</body>
</html>